# openXJV
Viewer for XJustiz files used for file / data transfers between courts, lawyers, agencies, etc. in  Germany's EGVP-System

openXJV ist ein **kostenloses Anzeigeprogramm für XJustiz-Dateien**, die im Rahmen des elektronischen Rechtsverkehrs bei der Übertragung von Dokumenten Verwendung finden.

Dies ist z. B. **für die Akteneinsicht in Akten der Bundesanstalt für Arbeit (BA)** relevant, 
  da diese auf elektronischem Wege lediglich Einzeldateien mit einem begleitenden XJustiz-Datensatz übermittelt. Erst das Auslesen des Datensatzes erzeugt aus der übermittelten "Dateisammlung" wieder eine sinnvolle Aktendarstellung.

**Es eignet sich auch zur Anzeige beliebiger XJustiz-Datensätze der "Schriftgutübermittlung" über beA, eBO, beN, etc.** 

openXJV ist entstanden, da zum Zeitpunkt des Projektstarts keine plattformübergreifende Anzeigelösung bereit stand.
  
**openXJV unterstützt den XJustiz-Standard in den Versionen 3.4.1, 3.3.1, 3.2.1 sowie 2.4.1**. Es werden die wichtigsten Datentypen und Strukturen unterstützt - eine vollständige und abolut fehlerfreie Anzeige kann jedoch nicht garantiert werden. 
**Fachverfahren werden nicht unterstützt.**

Das Benutzerhandbuch finden Sie in der Anwendung unter "Hilfe", auf Github im Unterverzeichnis "docs" 
oder zum Download auf https://openxjv.de  
